@@ -1,6 +1,7 @@
 from firexkit.argument_conversion import ConverterRegister
+from firexkit.task import flame_collapse
 from firexapp.engine.celery import app
-from firexapp.tasks.core_tasks import get_configured_root_task
+from firexapp.tasks.root_tasks import get_configured_root_task
 from firexapp.submit.reporting import ReportersRegistry
 from firexkit.task import flame_collapse
 
