@@ -199,15 +199,8 @@ def {0}(**kwargs):
             if expected_return is not None:
                 raise Exception("assert_expected_return_code should not return. It should assert if needed")
 
-            if self.tmp_json_file:
-                # Dealing with firex as an external process is non-trivial. There is no guarantee json_file
-                # will ever be populated, and it may be created after the console is released. Yikes. Guess
-                # the timeout value to avoid waiting in lots of cases when we know it will never appear, like
-                # invalid args or failed tracking services.
-                json_path_timeout = 10 if process.returncode == 0 else 0
-                exists = wait_until(os.path.isfile, timeout=json_path_timeout, sleep_for=0.2, path=self.tmp_json_file)
-                if exists:
-                    flow_test_config.run_data = load_completion_report(self.tmp_json_file)
+            if self.tmp_json_file and os.path.isfile(self.tmp_json_file):
+                flow_test_config.run_data = load_completion_report(self.tmp_json_file)
 
             if self.is_submit_command(flow_test_config) and process.returncode == 0 and \
                     self.is_instance_of_intercept(flow_test_config) and \
